OiRA

Help

1. Подготовка
2. Включване
3. Определяне + Оценяване
4. План за действие
5. Доклад
6. Статус 0%

# Докладване

Сега след като завършите определянето на всички рискове във Вашата организация и създадете план за действие, можете да създадете доклад, който изброява всички Ваши резултати. Можете, ако желаете, да добавите допълнителни коментари, които трябва да бъдат включени в този доклад в полето по-долу.

Запазване и продължаване

Scroll to top
Back

## report.html

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More